@@ -27,12 +27,15 @@ def getCoursesTaken(html):
     for i in range(len(html_text)):
         if (len(html_text[i]) == 4 and isAllCaps(html_text[i]) and 
             len(html_text[i+1]) == 4 and html_text[i+1].isdigit() and not
-            set([html_text[i+5], html_text[i+6]]) <= set(["F", "NC", "U", "W"])):
+            set([html_text[i+5], html_text[i+6]]) <= set(["F", "NC", "U", "W"]):
 	    name = html_text[i]+" "+html_text[i+1]
             if len(html_text[i+4]) == 6:
                 term = html_text[i+4]
             else:
                 term = html_text[i+5]
+            for course in courses:
+                if course.name == name:
+                    continue
             courses.append(Course(name, term))
     return courses
     
